@@ -7,7 +7,7 @@
  *      implementation of the pqxx::pipeline class
  *   Throughput-optimized query manager
  *
- * Copyright (c) 2003-2004, Jeroen T. Vermeulen <jtv@xs4all.nl>
+ * Copyright (c) 2003-2005, Jeroen T. Vermeulen <jtv@xs4all.nl>
  *
  * See COPYING for copyright license.  If you did not receive a file called
  * COPYING with this source code, please notify the distributor of this mistake,
@@ -17,8 +17,6 @@
  */
 #include "pqxx/compiler.h"
 
-#include <algorithm>
-
 #include "pqxx/dbtransaction"
 #include "pqxx/pipeline"
 
@@ -118,7 +116,7 @@ bool pqxx::pipeline::is_finished(pipeline::query_id q) const
 {
   if (m_queries.find(q) == m_queries.end())
     throw logic_error("Requested status for unknown query " + to_string(q));
-  return (m_issuedrange.first==m_queries.end()) ||
+  return (QueryMap::const_iterator(m_issuedrange.first)==m_queries.end()) ||
          (q < m_issuedrange.first->first && q < m_error);
 }
 
@@ -301,7 +299,9 @@ void pqxx::pipeline::obtain_dummy()
 
 
   // Reset internal state to forget botched batch attempt
-  m_num_waiting += distance(m_issuedrange.first, stop);
+  // (Not using std::distance() because of problem with SunC++)
+  for (QueryMap::iterator i = m_issuedrange.first; i != stop; ++i)
+    ++m_num_waiting;
   m_issuedrange.second = m_issuedrange.first;
 
   pqxxassert(!m_dummy_pending);
@@ -333,7 +333,7 @@ void pqxx::pipeline::obtain_dummy()
     QueryMap::const_iterator q = m_issuedrange.first;
     set_error_at( (q == m_queries.end()) ?  thud + 1 : q->first);
 
-    pqxxassert(m_num_waiting == distance(m_issuedrange.second, m_queries.end()));
+    pqxxassert(m_num_waiting == distance(m_issuedrange.second,m_queries.end()));
   }
 
   pqxxassert(m_issuedrange.first != m_queries.end());
@@ -419,10 +419,12 @@ void pqxx::pipeline::receive(pipeline::QueryMap::const_iterator stop)
 
   if (m_dummy_pending) obtain_dummy();
 
-  while (obtain_result() && (m_issuedrange.first != stop));
+  while (obtain_result() &&
+         QueryMap::const_iterator(m_issuedrange.first) != stop);
 
   // Also haul in any remaining "targets of opportunity"
-  if (m_issuedrange.first == stop) get_further_available_results();
+  if (QueryMap::const_iterator(m_issuedrange.first) == stop)
+    get_further_available_results();
 }
 
 
