@@ -7,7 +7,7 @@
  *      implementation of the pqxx::transaction class.
  *   pqxx::transaction represents a regular database transaction
  *
- * Copyright (c) 2001-2003, Jeroen T. Vermeulen <jtv@xs4all.nl>
+ * Copyright (c) 2001-2004, Jeroen T. Vermeulen <jtv@xs4all.nl>
  *
  * See COPYING for copyright license.  If you did not receive a file called
  * COPYING with this source code, please notify the distributor of this mistake,
@@ -31,6 +31,14 @@ using namespace PGSTD;
 #define SQL_ROLLBACK_WORK 	"ROLLBACK"
 
 
+pqxx::basic_transaction::basic_transaction(connection_base &C,
+    const string &IsolationLevel,
+    const string &TName) :
+  dbtransaction(C, IsolationLevel, TName, "transaction<"+IsolationLevel+">")
+{
+}
+
+
 void pqxx::basic_transaction::do_begin()
 {
   start_backend_transaction();
