@@ -30,7 +30,8 @@ int main(int, char *argv[])
 
     result R( T.exec("SELECT * FROM pg_tables") );
 
-    for (result::const_iterator c = R.begin(); c != R.end(); ++c)
+    result::const_iterator c;
+    for (c = R.begin(); c != R.end(); ++c)
     {
       string N;
       c[0].to(N);
@@ -38,6 +39,21 @@ int main(int, char *argv[])
       cout << '\t' << to_string(c.num()) << '\t' << N << endl;
     }
 
+    // See if back() and tuple comparison work properly
+    if (R.size() < 2)
+      throw runtime_error("Not enough results in pg_tables to test, sorry!");
+    --c;
+    if (c->size() != R.back().size())
+      throw logic_error("Size mismatch between tuple iterator and back()");
+    const string nullstr;
+    for (result::tuple::size_type i = 0; i < c->size(); ++i)
+      if (c[i].as(nullstr) != R.back()[i].as(nullstr))
+	throw logic_error("Value mismatch in back()");
+    if (c != R.back())
+      throw logic_error("Something wrong with tuple inequality");
+    if (!(c == R.back()))
+      throw logic_error("Something wrong with tuple equality");
+
     // "Commit" the non-transaction.  This doesn't really do anything since
     // NonTransaction doesn't start a backend transaction.
     T.commit();
