@@ -13,48 +13,15 @@ using namespace PGSTD;
 using namespace pqxx;
 
 
-// Example program for libpqxx.  Send notification to self, using defered
+// Example program for libpqxx.  Send notification to self, using deferred
 // connection.
 //
 // Usage: test023
 
-#ifdef _WIN32
-#include <windows.h>
-#else
-extern "C"
-{
-#ifdef PQXX_HAVE_SYS_SELECT_H
-#include <sys/select.h>
-#else
-#include <sys/time.h>
-#include <sys/types.h>
-#include <unistd.h>
-#endif
-}
-#endif	// _WIN32
-
 
 namespace
 {
 
-#ifndef _WIN32
-// Reasonably portable way to sleep for a given number of milliseconds
-/* This definition is not needed on Windows, which provides its own Sleep()
- * function with the same semantics.
- */
-void Sleep(int ms)
-{
-  fd_set F;
-  FD_ZERO(&F);
-  struct timeval timeout;
-  timeout.tv_sec = ms / 1000;
-  timeout.tv_usec = (ms % 1000) * 1000;
-  if (select(0, &F, &F, &F, &timeout) == -1)
-    throw runtime_error(strerror(errno));
-}
-#endif	// _WIN32
-
-
 // Sample implementation of trigger handler
 class TestTrig : public trigger
 {
@@ -125,7 +92,7 @@ int main()
       if (notifs)
 	throw logic_error("Got " + to_string(notifs) + " "
 	    "unexpected notifications!");
-      Sleep(500);
+      pqxx::internal::sleep_seconds(1);
       notifs = C.get_notifs();
       cout << ".";
     }
