@@ -70,8 +70,9 @@ struct CountGreaterSmaller : unary_function<result::tuple, void>
   {
     // Count number of entries with key greater/smaller than first row's key
     // using std::count_if<>()
-    const long Greater = count_if(R.begin(), R.end(), bind2nd(Cmp(Key),T)),
-               Smaller = count_if(R.begin(), R.end(), bind1st(Cmp(Key),T));
+    const result::size_type
+      Greater = count_if(R.begin(), R.end(), bind2nd(Cmp(Key),T)),
+      Smaller = count_if(R.begin(), R.end(), bind1st(Cmp(Key),T));
 
     cout << "'" << T[Key] << "': " 
          << Greater << " greater, "
